#!/usr/bin/perl -w
#
###############################################################################
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################
#
#
# Converts ip_banishlst file for ipblocklist compatible ipset
#
# Rob Brewer 14 April 2022
#

use Net::CIDR::Lite;
use strict;

require '/var/ipfire/Banish/Banish-functions.pl';

my $filename = "/var/ipfire/Banish/ip_Banishlist";
my $blacklist = "/srv/web/ipfire/html/banish_list";


open(OUTFILE, ">$blacklist") or die 'Unable to open Banish list file.';
flock OUTFILE, 2;

open(INFILE, $filename) or die 'Unable to open Banish list file.';

    while ( <INFILE> )
     {
       my $line = $_;
       chomp($line);
    
	if (&Banish::validiprange($line) eq '1')
           {
		{
		# Convert ip-ranges to cidr format for ipsets
		my $cidr = Net::CIDR::Lite->new;
     	        $cidr->add_any($line);
 	 	my @cidr_list =  $cidr->list;
		print OUTFILE "$_\n" for @cidr_list;
		}
	   }

	elsif (&Banish::validfqdn($line) eq '1')
	   {
		# convert fqdn to ip address
		my @addresses = qx{dig +short $line};
	        print OUTFILE "$_" for @addresses;
	   }

        else
	   {
                print OUTFILE "$line\n";
	   }
     }
close(OUTFILE);
close(INFILE);
